This is the mail archive of the cygwin-apps-cvs mailing list for the cygwin-apps project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[calm - Cygwin server-side packaging maintenance script] branch master, updated. 20160705-74-gde1c676




https://sourceware.org/git/gitweb.cgi?p=cygwin-apps/calm.git;h=de1c67659c16cf63ba57695c4c2ab49a35ca72f7

commit de1c67659c16cf63ba57695c4c2ab49a35ca72f7
Author: Jon Turney <jon.turney@dronecode.org.uk>
Date:   Wed May 3 23:36:57 2017 +0100

    Don't bind version_hints to same dict when making from legacy hints
    
    This avoids any subsequent changes to the hints for a version from being
    applied to all versions.
    
    This allows the stability level tracking across versions to work correctly.
    
    This then exposes that wasn't working correctly for gcc, and x86 gcc has a
    timestamp anomaly that should have been ignoring...

https://sourceware.org/git/gitweb.cgi?p=cygwin-apps/calm.git;h=356854f810514021806d6402c6c16cfe048a8c3e

commit 356854f810514021806d6402c6c16cfe048a8c3e
Author: Jon Turney <jon.turney@dronecode.org.uk>
Date:   Sat Apr 29 13:46:12 2017 +0100

    Increase interval between scheduled runs from 30 mins to 4 hours


Diff:
---
 calm/calm.py          |    6 +++---
 calm/package.py       |    2 +-
 calm/past_mistakes.py |   20 ++++++++++++++++++++
 3 files changed, 24 insertions(+), 4 deletions(-)

diff --git a/calm/package.py b/calm/package.py
index 51decbf..ca48d2e 100755
--- a/calm/package.py
+++ b/calm/package.py
@@ -296,7 +296,7 @@ def read_package(packages, basedir, dirpath, files, strict=False, remove=[], upl
                 hint_files[vr] = hint_fn
             elif legacy:
                 # otherwise, use setup.hint
-                pvr_hint = hints
+                pvr_hint = hints.copy()
                 legacy_used = True
             else:
                 # it's an error to not have either a setup.hint or a pvr.hint
diff --git a/calm/past_mistakes.py b/calm/past_mistakes.py
index 3baa848..e24f152 100644
--- a/calm/past_mistakes.py
+++ b/calm/past_mistakes.py
@@ -143,9 +143,29 @@ empty_but_not_obsolete = [
 
 # packages with timestamp anomalies
 mtime_anomalies = [
+    'gcc-ada',
+    'gcc-cilkplus',
+    'gcc-core',
+    'gcc-debuginfo',
+    'gcc-fortran',
+    'gcc-g++',
+    'gcc-java',
+    'gcc-objc',
+    'gcc-objc++',
     'gcc-tools-epoch2-autoconf',
     'glproto',
     'gv-debuginfo',
+    'libatomic1',
+    'libcilkrts5',
+    'libgcc1',
+    'libgcj-common',
+    'libgcj16',
+    'libgfortran3',
+    'libgomp1',
+    'libobjc4',
+    'libquadmath0',
+    'libssp0',
+    'libstdc++6',
     'python-gtk2.0',
     'python-gtk2.0-demo',
     'python-gtk2.0-devel',


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
diff --git a/calm/calm.py b/calm/calm.py
index afb98bd..e8fb9a2 100755
--- a/calm/calm.py
+++ b/calm/calm.py
@@ -511,10 +511,10 @@ def do_daemon(args, state):
                         if read_uploads:
                             continue
 
                 # we wake at a 10 minute offset from the next 30 minute boundary
                 # (i.e. at :10 or :40 past the hour) to check the state of the
                 # release area, in case someone has ninja-ed in a change there...
-                interval = 30*60
+                interval = 240*60
                 offset = 10*60
                 delay = interval - ((time.time() - offset) % interval)
                 signal.alarm(int(delay))
@@ -511,10 +511,10 @@ def do_daemon(args, state):
                             continue
 
-                # we wake at a 10 minute offset from the next 30 minute boundary
-                # (i.e. at :10 or :40 past the hour) to check the state of the
+                # we wake at a 10 minute offset from the next 240 minute boundary
+                # (i.e. at :10 past every fourth hour) to check the state of the
                 # release area, in case someone has ninja-ed in a change there...